#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
#
#     Part of "Nuitka", an optimizing Python compiler that is compatible and
#     integrates with CPython, but also works on its own.
#
#     Licensed under the Apache License, Version 2.0 (the "License");
#     you may not use this file except in compliance with the License.
#     You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#     Unless required by applicable law or agreed to in writing, software
#     distributed under the License is distributed on an "AS IS" BASIS,
#     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#     See the License for the specific language governing permissions and
#     limitations under the License.
#
""" Release: Create Windows MSI files for Nuitka

"""

import os
import shutil

from nuitka.tools.Basics import goHome
from nuitka.tools.release.MSI import createMSIPackage


def main():
    goHome()

    msi_filename = createMSIPackage()

    if not os.path.exists("msi"):
        os.makedirs("msi")

    shutil.move(msi_filename, "msi")


if __name__ == "__main__":
    main()
